<?php

namespace Cart\Orderpostmate\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Cart\Orderpostmate\Http\Requests\OrderpostmateRequest;
use Cart\Orderpostmate\Interfaces\OrderpostmateRepositoryInterface;
use Cart\Orderpostmate\Models\Orderpostmate;

/**
 * Resource controller class for orderpostmate.
 */
class OrderpostmateResourceController extends BaseController
{

    /**
     * Initialize orderpostmate resource controller.
     *
     * @param type OrderpostmateRepositoryInterface $orderpostmate
     *
     * @return null
     */
    public function __construct(OrderpostmateRepositoryInterface $orderpostmate)
    {
        parent::__construct();
        $this->repository = $orderpostmate;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Cart\Orderpostmate\Repositories\Criteria\OrderpostmateResourceCriteria::class);
    }

    /**
     * Display a list of orderpostmate.
     *
     * @return Response
     */
    public function index(OrderpostmateRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Cart\Orderpostmate\Repositories\Presenter\OrderpostmatePresenter::class)
                ->$function();
        }

        $orderpostmates = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('orderpostmate::orderpostmate.names'))
            ->view('orderpostmate::orderpostmate.index', true)
            ->data(compact('orderpostmates', 'view'))
            ->output();
    }

    /**
     * Display orderpostmate.
     *
     * @param Request $request
     * @param Model   $orderpostmate
     *
     * @return Response
     */
    public function show(OrderpostmateRequest $request, Orderpostmate $orderpostmate)
    {

        if ($orderpostmate->exists) {
            $view = 'orderpostmate::orderpostmate.show';
        } else {
            $view = 'orderpostmate::orderpostmate.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('orderpostmate::orderpostmate.name'))
            ->data(compact('orderpostmate'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new orderpostmate.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OrderpostmateRequest $request)
    {

        $orderpostmate = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('orderpostmate::orderpostmate.name')) 
            ->view('orderpostmate::orderpostmate.create', true) 
            ->data(compact('orderpostmate'))
            ->output();
    }

    /**
     * Create new orderpostmate.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OrderpostmateRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $orderpostmate                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('orderpostmate::orderpostmate.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('orderpostmate/orderpostmate/' . $orderpostmate->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/orderpostmate/orderpostmate'))
                ->redirect();
        }

    }

    /**
     * Show orderpostmate for editing.
     *
     * @param Request $request
     * @param Model   $orderpostmate
     *
     * @return Response
     */
    public function edit(OrderpostmateRequest $request, Orderpostmate $orderpostmate)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('orderpostmate::orderpostmate.name'))
            ->view('orderpostmate::orderpostmate.edit', true)
            ->data(compact('orderpostmate'))
            ->output();
    }

    /**
     * Update the orderpostmate.
     *
     * @param Request $request
     * @param Model   $orderpostmate
     *
     * @return Response
     */
    public function update(OrderpostmateRequest $request, Orderpostmate $orderpostmate)
    {
        try {
            $attributes = $request->all();

            $orderpostmate->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('orderpostmate::orderpostmate.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('orderpostmate/orderpostmate/' . $orderpostmate->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('orderpostmate/orderpostmate/' . $orderpostmate->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the orderpostmate.
     *
     * @param Model   $orderpostmate
     *
     * @return Response
     */
    public function destroy(OrderpostmateRequest $request, Orderpostmate $orderpostmate)
    {
        try {

            $orderpostmate->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('orderpostmate::orderpostmate.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('orderpostmate/orderpostmate/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('orderpostmate/orderpostmate/' . $orderpostmate->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple orderpostmate.
     *
     * @param Model   $orderpostmate
     *
     * @return Response
     */
    public function delete(OrderpostmateRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('orderpostmate::orderpostmate.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('orderpostmate/orderpostmate'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/orderpostmate/orderpostmate'))
                ->redirect();
        }

    }

    /**
     * Restore deleted orderpostmates.
     *
     * @param Model   $orderpostmate
     *
     * @return Response
     */
    public function restore(OrderpostmateRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('orderpostmate::orderpostmate.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/orderpostmate/orderpostmate'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/orderpostmate/orderpostmate/'))
                ->redirect();
        }

    }

}
