<?php

namespace Cart\Orderpostmates\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cart\Orderpostmates\Models\Orderpostmate;

class OrderpostmatePolicy
{

    /**
     * Determine if the given user can view the orderpostmate.
     *
     * @param UserPolicy $user
     * @param Orderpostmate $orderpostmate
     *
     * @return bool
     */
    public function view(UserPolicy $user, Orderpostmate $orderpostmate)
    {
        if ($user->canDo('orderpostmates.orderpostmate.view') && $user->isAdmin()) {
            return true;
        }

        return $orderpostmate->user_id == user_id() && $orderpostmate->user_type == user_type();
    }

    /**
     * Determine if the given user can create a orderpostmate.
     *
     * @param UserPolicy $user
     * @param Orderpostmate $orderpostmate
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('orderpostmates.orderpostmate.create');
    }

    /**
     * Determine if the given user can update the given orderpostmate.
     *
     * @param UserPolicy $user
     * @param Orderpostmate $orderpostmate
     *
     * @return bool
     */
    public function update(UserPolicy $user, Orderpostmate $orderpostmate)
    {
        if ($user->canDo('orderpostmates.orderpostmate.edit') && $user->isAdmin()) {
            return true;
        }

        return $orderpostmate->user_id == user_id() && $orderpostmate->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given orderpostmate.
     *
     * @param UserPolicy $user
     * @param Orderpostmate $orderpostmate
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Orderpostmate $orderpostmate)
    {
        return $orderpostmate->user_id == user_id() && $orderpostmate->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given orderpostmate.
     *
     * @param UserPolicy $user
     * @param Orderpostmate $orderpostmate
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Orderpostmate $orderpostmate)
    {
        if ($user->canDo('orderpostmates.orderpostmate.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given orderpostmate.
     *
     * @param UserPolicy $user
     * @param Orderpostmate $orderpostmate
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Orderpostmate $orderpostmate)
    {
        if ($user->canDo('orderpostmates.orderpostmate.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
